function facpack
% The toolbox FAC-PACK provides software for the following problems in
% multivariate curve resolution:
% 1. baseline correction,
% 2. computation of multi-component factorizations and the area of feasible
%    solutions,
% 3. combination of complementarity and AFS theory
% Copyright (c) 2013 Mathias Sawall, University of Rostock, Department of Mathematics.
% 
% The software can be used for academic, research and other similar noncommercial uses. The user
% acknowledges that this software is still in the development stage and that it is provided by the
% copyright holders and contributors "as is" and any express or implied warranties, fitness for a
% particular purpose are disclaimed. In no event shall the copyright owner or contributors be liable
% for any direct, indirect, incidental, special, exemplary, or consequential damages.
% 
% The copyright holders provide no reassurances that the source code provided does not infringe any
% patent, copyright, or any other intellectual property rights of third parties. The copyright
% holders disclaim any liability to any recipient for claims brought against recipient by any third
% party for infringement of that parties intellectual property rights.
% 
% The user has to respect the lapack license, see http://www.netlib.org/lapack/LICENSE.txt, and
% the license for the ACM routine nl2sol, see http://www.acm.org/publications/policies/softwarecrnotice,
% which are used in the associated C-code.

version = 1.10;
fname = mfilename;
calcf = mfilename('fullpath');
calcf = calcf(1:end-length(fname));
path(path, calcf);

fig = figure(10);
pause(.1);

scrsz = get(0,'ScreenSize');

set(fig,'Position',[scrsz(3)/4 scrsz(4)/3 scrsz(3)/3 scrsz(4)/3]);

pause(.5);
figpos = get(fig,'Position');

set(fig,'Name',['FAC - PACK (version ',num2str(version, '%2.2f'),')'],'NumberTitle','off','MenuBar','none','Toolbar','none','color','white');

if isunix
    basicfsz = figpos(4)/70;
    basichi = basicfsz/150;
else
    basicfsz = figpos(3)/140;
    basichi = basicfsz/110;
end

Styles = {'bitstream charter';'clean';'Courier';'courier 10 pitch';'frank ruehl';'Helvetica';'Helvetica-Narrow';'itc bookman';'urw bookman l'};
sty = Styles{6};
bgc = 0.95*ones(3,1);

nt = 1;
nb = 1;

Toolinfo(nt) = uicontrol('Style','text','String',sprintf('Baseline correction for a series of spectra.'),...
    'HorizontalAlignment','left','Fontsize',2*basicfsz,'BackgroundColor',bgc,...
    'Units','normalized','FontName',sty,'Position',[0.47, 0.7, 0.48, 0.25]);
nt = nt+1;

Toolinfo(nt) = uicontrol('Style','text','String',sprintf('Computation of multi-component factorizations and the area of feasible solutions by the polygon inflation algorithm.'),...
    'HorizontalAlignment','left','Fontsize',2*basicfsz,'BackgroundColor',bgc,...
    'Units','normalized','FontName',sty,'Position',[0.47, 0.4, 0.48, 0.25]);
nt = nt+1;

Toolinfo(nt) = uicontrol('Style','text','String',sprintf('Simultaneous representation of the spectral and concentrational AFS and reduction of the rotational ambiguity by the complementarity theorem.'),...
    'HorizontalAlignment','left','Fontsize',2*basicfsz,'BackgroundColor',bgc,...
    'Units','normalized','FontName',sty,'Position',[0.47, 0.1, 0.48, 0.25]);
nt = nt+1;

Button(nt) = uicontrol('Style','pushbutton','String','Baseline correction','HorizontalAlignment','left','Fontsize',2*basicfsz,'FontWeight','bold',...
    'Units','normalized','FontName',sty,'Position',[0.05, 0.7, 0.4, 0.25],'Callback',{@buttonBLA, version});
nb = nb+1;

Button(nt) = uicontrol('Style','pushbutton','String','AFS computation','HorizontalAlignment','left','Fontsize',2*basicfsz,'FontWeight','bold',...
    'Units','normalized','FontName',sty,'Position',[0.05, 0.4, 0.4, 0.25],'Callback',{@buttonAFS, version});
nb = nb+1;

Button(nt) = uicontrol('Style','pushbutton','String','Complementarity & AFS','HorizontalAlignment','left','Fontsize',2*basicfsz,'FontWeight','bold',...
    'Units','normalized','FontName',sty,'Position',[0.05, 0.1, 0.4, 0.25],'Callback',{@buttonCAA, version});
nb = nb+1;


function buttonBLA(hObject, eventdata, version)
subGUI4BLA(version);

function buttonAFS(hObject, eventdata, version)
subGUI4AFS(version);

function buttonCAA(hObject, eventdata, version)
subGUI4CAA(version);
